==> QtBitcoinTrader-1.08.01.tar.gz: QtBitcoinTrader-1.08.01/src/currencypairitem.h <==
//  This file is part of Qt Bitcion Trader
//      https://github.com/JulyIGHOR/QtBitcoinTrader
//  Copyright (C) 2013-2014 July IGHOR <julyighor@gmail.com>
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  In addition, as a special exception, the copyright holders give
//  permission to link the code of portions of this program with the
//  OpenSSL library under certain conditions as described in each
//  individual source file, and distribute linked combinations including
//  the two.
//
//  You must obey the GNU General Public License in all respects for all
//  of the code used other than OpenSSL. If you modify file(s) with this
//  exception, you may extend this exception to your version of the
//  file(s), but you are not obligated to do so. If you do not wish to do
//  so, delete this exception statement from your version. If you delete
//  this exception statement from all source files in the program, then
//  also delete it here.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef CURRENCYPAIRITEM_H
#define CURRENCYPAIRITEM_H

#include "currencyinfo.h"

struct CurrencyPairItem
{
	CurrencyPairItem();

	void setSymbol(QByteArray symb);

	QString currAName;
	QString name;

	CurencyInfo currAInfo;
	CurencyInfo currBInfo;

    QString symbol;
	QString symbolSecond(){return symbol+currRequestSecond;}
	QByteArray currRequestPair;
	QByteArray currRequestSecond;

    QString currAStr;
    QString currAStrLow;
    QString currASign;

    QString currBStr;
    QString currBStrLow;
    QString currBSign;

    qreal priceMin;//qPow(0.1,priceDecimals);
    //qreal priceMax;
    qreal tradePriceMin;
    qreal tradeVolumeMin;

	int priceDecimals;
	int currADecimals;
	int currBDecimals;
	int currABalanceDecimals;
	int currBBalanceDecimals;
};

#endif // CURRENCYPAIRITEM_H

==> QtBitcoinTrader-1.10.01.tar.gz: QtBitcoinTrader-1.10.01/src/currencypairitem.h <==
//  This file is part of Qt Bitcion Trader
//      https://github.com/JulyIGHOR/QtBitcoinTrader
//  Copyright (C) 2013-2015 July IGHOR <julyighor@gmail.com>
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  In addition, as a special exception, the copyright holders give
//  permission to link the code of portions of this program with the
//  OpenSSL library under certain conditions as described in each
//  individual source file, and distribute linked combinations including
//  the two.
//
//  You must obey the GNU General Public License in all respects for all
//  of the code used other than OpenSSL. If you modify file(s) with this
//  exception, you may extend this exception to your version of the
//  file(s), but you are not obligated to do so. If you do not wish to do
//  so, delete this exception statement from your version. If you delete
//  this exception statement from all source files in the program, then
//  also delete it here.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef CURRENCYPAIRITEM_H
#define CURRENCYPAIRITEM_H

#include "currencyinfo.h"

struct CurrencyPairItem
{
	CurrencyPairItem();

	void setSymbol(QByteArray symb);

	QString currAName;
	QString name;

	CurencyInfo currAInfo;
	CurencyInfo currBInfo;

    QString symbol;
    QString symbolSecond() const {return symbol+currRequestSecond;}
	QByteArray currRequestPair;
	QByteArray currRequestSecond;

    QString currAStr;
    QString currAStrLow;
    QString currASign;

    QString currBStr;
    QString currBStrLow;
    QString currBSign;

    double priceMin;//qPow(0.1,priceDecimals);
    //double priceMax;
    double tradePriceMin;
    double tradeVolumeMin;

	int priceDecimals;
	int currADecimals;
	int currBDecimals;
	int currABalanceDecimals;
	int currBBalanceDecimals;
};

#endif // CURRENCYPAIRITEM_H
